@@ -65,10 +65,10 @@ DiagramDrawItem::DiagramDrawItem(const QJsonObject &json, QMenu *contextMenu):Di
     qreal height=json["height"].toDouble();
     myPos2=QPointF(width,height);
     myRadius=5.0;
-    qreal x0=json["start_x"].toDouble();
-    qreal y0=json["start_y"].toDouble();
-    qreal x1=json["end_x"].toDouble();
-    qreal y1=json["end_y"].toDouble();
+    qreal x0=json["x0"].toDouble();
+    qreal y0=json["y0"].toDouble();
+    qreal x1=json["x1"].toDouble();
+    qreal y1=json["y1"].toDouble();
     mStartPoint=QPointF(x0,y0);
     mEndPoint=QPointF(x1,y1);
 
@@ -155,6 +155,7 @@ QPainterPath DiagramDrawItem::createPath()
         path.lineTo(myRadius,0);
         break;
     case Pie:
+    case CirclePie:
     {
         qreal compression=myPos2.y()/myPos2.x(); // calculate compression because it is an ellipse instead of a circle
         QLineF ln(0,0,mStartPoint.x(),mStartPoint.y()/compression);
@@ -254,7 +255,7 @@ void DiagramDrawItem::write(QJsonObject &json)
     json["diagramtype"]=static_cast<int>(myDiagramType);
     json["width"]=myPos2.x();
     json["height"]=myPos2.y();
-    if(myDiagramType==Pie){
+    if(myDiagramType==Pie || myDiagramType==CirclePie){
         json["x0"]=mStartPoint.x();
         json["y0"]=mStartPoint.y();
         json["x1"]=mEndPoint.x();
@@ -272,7 +273,7 @@ void DiagramDrawItem::setPos2(QPointF newPos)
 {
     prepareGeometryChange();
     myPos2=mapFromScene(newPos);
-    if(myDiagramType==Circle || myDiagramType==Square){
+    if(myDiagramType==Circle || myDiagramType==Square || myDiagramType==CirclePie){
         // special treatment in case of circle
         if(fabs(myPos2.x())>fabs(myPos2.y())){
             if(myPos2.y()<0) myPos2.setY(-fabs(myPos2.x()));
@@ -303,7 +304,7 @@ void DiagramDrawItem::setDimension(QPointF newPos)
 
 void DiagramDrawItem::mySetDimension(QPointF newPos)
 {
-    if(myDiagramType==Circle|| myDiagramType==Square){
+    if(myDiagramType==Circle|| myDiagramType==Square || myDiagramType==CirclePie){
         // special treatment in case of circle
         if(myPos2.x()!=newPos.x()){
             myPos2=newPos;
@@ -344,7 +345,7 @@ QPointF DiagramDrawItem::getHandler(int i) const
 int DiagramDrawItem::getNumberOfHandles() const
 {
     int nHandles=8;
-    if(myDiagramType==Pie){
+    if(myDiagramType==Pie || myDiagramType==CirclePie){
         nHandles=10;
     }
     return nHandles;
@@ -361,7 +362,7 @@ QPointF DiagramDrawItem::getDimension()
 void DiagramDrawItem::setStartPoint(const QPointF pt)
 {
     mStartPoint=pt;
-    if(myDiagramType==Pie){
+    if(myDiagramType==Pie || myDiagramType==CirclePie){
         mPainterPath=createPath();
     }
     if(m_partnerItem){
@@ -376,7 +377,7 @@ void DiagramDrawItem::setStartPoint(const QPointF pt)
 void DiagramDrawItem::setEndPoint(const QPointF pt)
 {
     mEndPoint=pt;
-    if(myDiagramType==Pie){
+    if(myDiagramType==Pie || myDiagramType==CirclePie){
         mPainterPath=createPath();
     }
     if(m_partnerItem){
@@ -427,7 +428,7 @@ void DiagramDrawItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *,
         painter->setPen(selPen);
         QRectF rect=innerBoundingRect();
         painter->drawRect(rect);
-        if(myDiagramType==Pie){
+        if(myDiagramType==Pie || myDiagramType==CirclePie){
             // extra lines for pie/arc
             painter->drawLine(myPos2/2,mStartPoint+myPos2/2);
             painter->drawLine(myPos2/2,mEndPoint+myPos2/2);
@@ -455,6 +456,26 @@ void DiagramDrawItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *,
     }// if
 }
 
+/*!
+ * \brief handle mouse enter hovering
+ * \param e
+ */
+void DiagramDrawItem::hoverEnterEvent(QGraphicsSceneHoverEvent *e)
+{
+    if (isSelected()) {
+        QPointF hover_point = e -> pos();
+        QPointF point;
+        int numberOfHandles=getNumberOfHandles();
+        for(myHoverPoint=0;myHoverPoint<numberOfHandles;myHoverPoint++){
+            point=getHandler(myHoverPoint);
+            if(hasClickedOn(hover_point,point)) break;
+        }//for
+        if(myHoverPoint==numberOfHandles) myHoverPoint=-1;
+        else update();
+    }
+    DiagramItem::hoverEnterEvent(e);
+}
+
 void DiagramDrawItem::hoverMoveEvent(QGraphicsSceneHoverEvent *e) {
     if (isSelected()) {
         QPointF hover_point = e -> pos();
@@ -482,10 +503,10 @@ void DiagramDrawItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *e) {
 
 bool DiagramDrawItem::hasClickedOn(QPointF press_point, QPointF point) const {
     return (
-        press_point.x() >= point.x() - myHandlerWidth &&\
-        press_point.x() <  point.x() + myHandlerWidth &&\
-        press_point.y() >= point.y() - myHandlerWidth &&\
-        press_point.y() <  point.y() + myHandlerWidth
+        press_point.x() >= point.x() - 2*myHandlerWidth &&\
+        press_point.x() <  point.x() + 2*myHandlerWidth &&\
+        press_point.y() >= point.y() - 2*myHandlerWidth &&\
+        press_point.y() <  point.y() + 2*myHandlerWidth
     );
 }
 
@@ -522,7 +543,7 @@ QRectF DiagramDrawItem::boundingRect() const
 
     QRectF newRect = innerBoundingRect().adjusted(-extra, -extra, extra, extra);
 
-    if(myDiagramType==Pie){
+    if(myDiagramType==Pie || myDiagramType==CirclePie){
         QRectF helper(mStartPoint+myPos2/2,mEndPoint+myPos2/2);
         newRect=newRect.united(helper);
     }
@@ -536,7 +557,7 @@ QRectF DiagramDrawItem::boundingRect() const
 QRectF DiagramDrawItem::innerBoundingRect() const
 {
     QRectF newRect = path().boundingRect();
-    if(myDiagramType==Pie){
+    if(myDiagramType==Pie || myDiagramType==CirclePie){
         newRect=QRectF(QPointF(0,0),myPos2);
     }
 
