@@ -229,6 +229,7 @@ void DiagramScene::setMode(DiagramScene::Mode mode, bool m_abort)
     case InsertText:
     case InsertUserElement:
     case InsertElement:
+    case InsertImage:
     case InsertLine:
     case InsertSpline:
         removePartnerItem();
@@ -627,6 +628,7 @@ void DiagramScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
             break;
         case InsertItem:
         case InsertElement:
+        case InsertImage:
         case InsertUserElement:
             if (insertedItem){
                 insertedItem=nullptr;
@@ -798,6 +800,33 @@ void DiagramScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
             emit abortSignal();
         }
         break;
+    case InsertImage:
+        if(insertedItem==nullptr){
+            insertedItem = new DiagramImage(mItemFileName, myItemMenu);
+            insertedItem->setZValue(m_maxZ);
+            m_maxZ+=0.1;
+            addItem(insertedItem);
+        }
+        insertedItem->setPos(onGrid(mouseEvent->scenePos()));
+        emit itemInserted(insertedItem);
+        insertedItem->setSelected(false);
+        insertedItem->setEnabled(false);
+        // add next item, same orientation if rotated/flipped
+        {
+            DiagramItem *item=new DiagramImage(mItemFileName, myItemMenu);
+            item->setZValue(m_maxZ);
+            item->setTransform(insertedItem->transform());
+            item->setSelected(true);
+            m_maxZ+=0.1;
+            addItem(item);
+            insertedItem=item;
+        }
+        takeSnapshot();
+        if(middleButton){
+            // switch toolbar !!
+            emit abortSignal();
+        }
+        break;
     case InsertUserElement:
         if(insertedItem==nullptr){
             insertedItem = load_userElement(mItemFileName);
@@ -1002,6 +1031,16 @@ void DiagramScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
         }
         insertedItem->setPos(onGrid(mouseEvent->scenePos()));
         break;
+    case InsertImage:
+        if(insertedItem==nullptr){
+            insertedItem = new DiagramImage(mItemFileName, myItemMenu);
+            insertedItem->setSelected(true);
+            insertedItem->setZValue(m_maxZ);
+            m_maxZ+=0.1;
+            addItem(insertedItem);
+        }
+        insertedItem->setPos(onGrid(mouseEvent->scenePos()));
+        break;
     case InsertUserElement:
         if(insertedItem==nullptr){
             insertedItem = load_userElement(mItemFileName);
@@ -1370,6 +1409,21 @@ void DiagramScene::pasteFromBuffer(QByteArray buffer)
 
     myMode=CopyingItem;
 }
+/*! paste image from clipboard
+ * \param img image to paste
+ */
+void DiagramScene::pasteImage(QImage img)
+{
+    if(img.isNull()) return;
+    setMode(InsertImage);
+    DiagramImage *di=new DiagramImage("", myItemMenu);
+    di->setImage(img);
+    insertedItem = di;
+    insertedItem->setSelected(true);
+    insertedItem->setZValue(m_maxZ);
+    m_maxZ+=0.1;
+    addItem(insertedItem);
+}
 
 /*!
  * \brief to be called when selection has changed
@@ -1664,6 +1718,7 @@ void DiagramScene::abort(bool keepSelection)
         break;
     case InsertItem:
     case InsertElement:
+    case InsertImage:
     case InsertUserElement:
         if(insertedItem)
             removeItem(insertedItem);
@@ -1846,6 +1901,10 @@ QGraphicsItem *DiagramScene::getElementFromJSON(QJsonObject json)
         insertedItem = new DiagramElement(json,myItemMenu);
         item=insertedItem;
         break;
+    case DiagramImage::Type:
+        insertedItem = new DiagramImage(json,myItemMenu);
+        item=insertedItem;
+        break;
     case DiagramDrawItem::Type:
         insertedDrawItem = new DiagramDrawItem(json,myItemMenu);
         item=insertedDrawItem;
