@@ -43,7 +43,7 @@ int main(int argc, char *argv[])
     const QStringList uiLanguages = QLocale::system().uiLanguages();
     for (const QString &locale : uiLanguages) {
         const QString baseName = "qdia_" + QLocale(locale).name();
-        QString fn=qApp->applicationDirPath()+"/translations/" + baseName;
+        QString fn=":/i18n/translation/" + baseName+".qm";
         if (translator.load(fn)) {
             a.installTranslator(&translator);
             break;
